==> api-vertx-client-0.7.20.6.1-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/MultisigRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.ModelError;
import io.nem.sdk.openapi.vertx.model.MultisigAccountGraphInfoDTO;
import io.nem.sdk.openapi.vertx.model.MultisigAccountInfoDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2020-01-01T18:24:23.294947664-03:00[America/Argentina/Buenos_Aires]")
public class MultisigRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.MultisigRoutesApi delegate;

	public MultisigRoutesApi(io.nem.sdk.openapi.vertx.api.MultisigRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.MultisigRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get multisig account information
     * Returns the multisig account information.
     * @param accountId Account public key or address. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getAccountMultisig(String accountId, Handler<AsyncResult<MultisigAccountInfoDTO>> resultHandler) {
        delegate.getAccountMultisig(accountId, resultHandler);
    }

    /**
     * Get multisig account information
     * Returns the multisig account information.
     * @param accountId Account public key or address. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MultisigAccountInfoDTO> rxGetAccountMultisig(String accountId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getAccountMultisig(accountId, fut);
        }));
    }
    /**
     * Get multisig account graph information
     * Returns the multisig account graph.
     * @param accountId Account public key or address. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getAccountMultisigGraph(String accountId, Handler<AsyncResult<List<MultisigAccountGraphInfoDTO>>> resultHandler) {
        delegate.getAccountMultisigGraph(accountId, resultHandler);
    }

    /**
     * Get multisig account graph information
     * Returns the multisig account graph.
     * @param accountId Account public key or address. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<MultisigAccountGraphInfoDTO>> rxGetAccountMultisigGraph(String accountId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getAccountMultisigGraph(accountId, fut);
        }));
    }

    public static MultisigRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.MultisigRoutesApi arg) {
        return arg != null ? new MultisigRoutesApi(arg) : null;
    }
}

==> api-vertx-client-0.7.21-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/MultisigRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.ModelError;
import io.nem.sdk.openapi.vertx.model.MultisigAccountGraphInfoDTO;
import io.nem.sdk.openapi.vertx.model.MultisigAccountInfoDTO;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2019-11-23T10:26:45.594287+01:00[Europe/Madrid]")
public class MultisigRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.MultisigRoutesApi delegate;

	public MultisigRoutesApi(io.nem.sdk.openapi.vertx.api.MultisigRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.MultisigRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get multisig account information
     * Returns the multisig account information.
     * @param accountId Account public key or address. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getAccountMultisig(String accountId, Handler<AsyncResult<MultisigAccountInfoDTO>> resultHandler) {
        delegate.getAccountMultisig(accountId, resultHandler);
    }

    /**
     * Get multisig account information
     * Returns the multisig account information.
     * @param accountId Account public key or address. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MultisigAccountInfoDTO> rxGetAccountMultisig(String accountId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getAccountMultisig(accountId, fut);
        }));
    }
    /**
     * Get multisig account graph information
     * Returns the multisig account graph.
     * @param accountId Account public key or address. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getAccountMultisigGraph(String accountId, Handler<AsyncResult<List<MultisigAccountGraphInfoDTO>>> resultHandler) {
        delegate.getAccountMultisigGraph(accountId, resultHandler);
    }

    /**
     * Get multisig account graph information
     * Returns the multisig account graph.
     * @param accountId Account public key or address. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<MultisigAccountGraphInfoDTO>> rxGetAccountMultisigGraph(String accountId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getAccountMultisigGraph(accountId, fut);
        }));
    }

    public static MultisigRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.MultisigRoutesApi arg) {
        return arg != null ? new MultisigRoutesApi(arg) : null;
    }
}
